:hide-toc:

.. container::
   :name: forkongithub

   `Fork on GitHub <https://github.com/agile-geoscience/striplog>`_


Striplog: Intervals of rocks and things
=======================================

    | ``striplog`` facilitates the loading, processing, and analysis of striplogs and other sequential data in the subsurface (stratigraphy, chronostratigraphy, and so on). 


User guide
----------

.. toctree::
   :caption: User guide
   :maxdepth: 2

   installation
   tutorial/01_Basics.ipynb
   tutorial/02_Basic_objects.ipynb
   tutorial/03_Display_objects.ipynb
   howto


API reference
-------------

.. toctree::
    :maxdepth: 2
    :caption: API reference

    api/striplog


Other resources
---------------

.. toctree::
    :maxdepth: 1
    :caption: Other resources

    development
    contributing
    authors
    license
    changelog


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. toctree::
    :caption: Project links
    :hidden:

    PyPI releases <https://pypi.org/project/striplog/>
    Code in GitHub <https://github.com/agile-geoscience/striplog>
    Issue tracker <https://github.com/agile-geoscience/striplog/issues>
    Community guidelines <https://code.agilescientific.com/community>
    Agile's software <https://code.agilescientific.com>
    Agile's website <https://www.agilescientific.com>
